# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ocellus_dataflow_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ocellus_types_pb2 as ocellus__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eocellus_dataflow_service.proto\x12\x07ocellus\x1a\x13ocellus_types.proto\"\'\n\x07Options\x12\x1c\n\x14sendPreDataflowEvent\x18\x01 \x01(\x08\"}\n\x06\x46ilter\x12\x18\n\x10pipelineIdFilter\x18\x01 \x03(\x03\x12\x16\n\x0eitemTypeFilter\x18\x02 \x03(\t\x12)\n\x0e\x64\x61taTypeFilter\x18\x03 \x03(\x0e\x32\x11.ocellus.DataType\x12\x16\n\x0emoduleIdFilter\x18\x04 \x03(\t\"]\n\x0b\x42indMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x0f.ocellus.Filter\x12!\n\x07options\x18\x03 \x01(\x0b\x32\x10.ocellus.Options\"\x12\n\x10PreDataflowEvent\",\n\rDataflowEvent\x12\x1b\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\r.ocellus.Data\"1\n\rDataflowError\x12\x10\n\x08moduleId\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrors\x18\x02 \x03(\t\"<\n\x12\x44\x61taflowErrorEvent\x12&\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x16.ocellus.DataflowError\"\xfc\x01\n\x16\x44\x61taflowStreamingEvent\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0f\n\x07\x66rameId\x18\x02 \x01(\x03\x12\x12\n\npipelineId\x18\x03 \x01(\x03\x12\x35\n\x10preDataflowEvent\x18\x04 \x01(\x0b\x32\x19.ocellus.PreDataflowEventH\x00\x12/\n\rdataflowEvent\x18\x05 \x01(\x0b\x32\x16.ocellus.DataflowEventH\x00\x12\x39\n\x12\x64\x61taflowErrorEvent\x18\x06 \x01(\x0b\x32\x1b.ocellus.DataflowErrorEventH\x00\x42\x07\n\x05\x65vent2\xa9\x01\n\x16OcellusDataflowService\x12\x46\n\tBindAsync\x12\x14.ocellus.BindMessage\x1a\x1f.ocellus.DataflowStreamingEvent\"\x00\x30\x01\x12G\n\x08\x42indSync\x12\x14.ocellus.BindMessage\x1a\x1f.ocellus.DataflowStreamingEvent\"\x00(\x01\x30\x01\x42u\n\x18ocellus.servers.dataflowB\x16OcellusDataflowServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x03OSD\xaa\x02\x18Ocellus.Servers.Dataflowb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ocellus_dataflow_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ocellus.servers.dataflowB\026OcellusDataflowServiceP\001Z\036github.com/byte-motion/ocellus\242\002\003OSD\252\002\030Ocellus.Servers.Dataflow'
  _OPTIONS._serialized_start=64
  _OPTIONS._serialized_end=103
  _FILTER._serialized_start=105
  _FILTER._serialized_end=230
  _BINDMESSAGE._serialized_start=232
  _BINDMESSAGE._serialized_end=325
  _PREDATAFLOWEVENT._serialized_start=327
  _PREDATAFLOWEVENT._serialized_end=345
  _DATAFLOWEVENT._serialized_start=347
  _DATAFLOWEVENT._serialized_end=391
  _DATAFLOWERROR._serialized_start=393
  _DATAFLOWERROR._serialized_end=442
  _DATAFLOWERROREVENT._serialized_start=444
  _DATAFLOWERROREVENT._serialized_end=504
  _DATAFLOWSTREAMINGEVENT._serialized_start=507
  _DATAFLOWSTREAMINGEVENT._serialized_end=759
  _OCELLUSDATAFLOWSERVICE._serialized_start=762
  _OCELLUSDATAFLOWSERVICE._serialized_end=931
# @@protoc_insertion_point(module_scope)
