# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/v1/ocellus_api_module_data_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,api/v1/ocellus_api_module_data_service.proto\x12\x1aocellus.api.v1.module.data\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\x91\x03\n\x14GetModuleDataRequest\x12Z\n\x08moduleId\x18\x01 \x01(\tBH\x92\x41\x45\x32\x43If provided, only data for the specified module id will be returned\x12\x66\n\x04path\x18\x02 \x01(\tBX\x92\x41U2SIf provided, it will only return the field which matches the path. Case insensitive\x12\xb4\x01\n\x04sort\x18\x03 \x01(\tB\xa5\x01\x92\x41\xa1\x01\x32\x9e\x01If provided, will sort according to query. Example: $.items[*].position.y:asc\nCurrently, only the follow ing supported:\n$.items[*].position.[x|y|z]:[asc|desc]\"\xca\x10\n\x12GetAllDataResponse\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct:\x89\x10\x92\x41\x85\x10\x32\x82\x10\x12\xff\x0f{\"modules\": [{\"timestamp\": 3194,\"frameId\": 63,\"rgbaImage\": \"/img/rgbaImage\",\"camera\": { \"name\": \"rs1\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }}},{\"timestamp\": 3200,\"frameId\": 63,\"camera\": { \"name\": \"img\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\",\"items\": []},{\"timestamp\": 2792,\"frameId\": 96,\"camera\": { \"name\": \"rs2\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 2792,\"frameId\": 96,\"items\": [],\"camera\": { \"name\": \"img2\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 3201,\"frameId\": 63,\"items\": [ {\"id\": 0,\"name\": \"blob1\",\"weight\": 0,\"confidence\": 1,\"color\": \"#0000FF\",\"dimension\": { \"width\": 0.044311594218015671, \"height\": 0.15963709354400635, \"depth\": 0.044311594218015671},\"position\": { \"x\": 0.28055679798126221, \"y\": 0.023770391941070557, \"z\": 0.038520518690347672},\"quaternion\": { \"w\": -0.018691437318921089, \"x\": 0.74761569499969482, \"y\": -0.044893074780702591, \"z\": -0.66234886646270752},\"orientation\": { \"pitch\": -5.01507568359375, \"yaw\": -97.0281982421875, \"roll\": -177.56260681152344},\"extremePoints\": {},\"pathPoints\": {},\"parentCamera\": \"rs1\" }],\"rgbaImage\": \"/img/rgbaImage\"}]}2\xb5\x03\n\x18OcellusModuleDataService\x12\xc3\x01\n\rGetModuleData\x12\x30.ocellus.api.v1.module.data.GetModuleDataRequest\x1a\x17.google.protobuf.Struct\"g\x92\x41-\x1a+Querys the data for the specified module id\x82\xd3\xe4\x93\x02\x31\x12\x12/api/v1/{moduleId}Z\x1b\x12\x19/api/v1/{moduleId}/{path}\x12\xac\x01\n\nGetAllData\x12\x30.ocellus.api.v1.module.data.GetModuleDataRequest\x1a..ocellus.api.v1.module.data.GetAllDataResponse\"<\x92\x41*\x1a(Returns all data produced by all modules\x82\xd3\xe4\x93\x02\t\x12\x07/api/v1\x1a$\x92\x41!\x12\x1fServes data produced by modulesB\x81\x01\n\x1e\x63om.ocellus.api.v1.module.dataB\x18OcellusModuleDataServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x05OAPMD\xaa\x02\x1aOcellus.Api.V1.Module.Datab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v1.ocellus_api_module_data_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.ocellus.api.v1.module.dataB\030OcellusModuleDataServiceP\001Z\036github.com/byte-motion/ocellus\242\002\005OAPMD\252\002\032Ocellus.Api.V1.Module.Data'
  _GETMODULEDATAREQUEST.fields_by_name['moduleId']._options = None
  _GETMODULEDATAREQUEST.fields_by_name['moduleId']._serialized_options = b'\222AE2CIf provided, only data for the specified module id will be returned'
  _GETMODULEDATAREQUEST.fields_by_name['path']._options = None
  _GETMODULEDATAREQUEST.fields_by_name['path']._serialized_options = b'\222AU2SIf provided, it will only return the field which matches the path. Case insensitive'
  _GETMODULEDATAREQUEST.fields_by_name['sort']._options = None
  _GETMODULEDATAREQUEST.fields_by_name['sort']._serialized_options = b'\222A\241\0012\236\001If provided, will sort according to query. Example: $.items[*].position.y:asc\nCurrently, only the follow ing supported:\n$.items[*].position.[x|y|z]:[asc|desc]'
  _GETALLDATARESPONSE._options = None
  _GETALLDATARESPONSE._serialized_options = b'\222A\205\0202\202\020\022\377\017{\"modules\": [{\"timestamp\": 3194,\"frameId\": 63,\"rgbaImage\": \"/img/rgbaImage\",\"camera\": { \"name\": \"rs1\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }}},{\"timestamp\": 3200,\"frameId\": 63,\"camera\": { \"name\": \"img\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\",\"items\": []},{\"timestamp\": 2792,\"frameId\": 96,\"camera\": { \"name\": \"rs2\", \"fov\": 58.165508270263672, \"position\": {\"x\": 0.0052760359831154346,\"y\": 0.058778464794158936,\"z\": -0.00064044661121442914 }, \"quaternion\": {\"w\": -0.74804270267486572,\"x\": -0.02558884397149086,\"y\": -0.66211831569671631,\"z\": 0.037104226648807526 }, \"orientation\": {\"pitch\": 5.0150761604309082,\"yaw\": 82.971817016601562,\"roll\": -1.243896484375 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 2792,\"frameId\": 96,\"items\": [],\"camera\": { \"name\": \"img2\", \"fov\": 53.130104064941406, \"position\": {\"x\": 0,\"y\": 0,\"z\": 0 }, \"quaternion\": {\"w\": 1,\"x\": 0,\"y\": 0,\"z\": 0 }, \"orientation\": {\"pitch\": -0,\"yaw\": 0,\"roll\": 0 }},\"rgbaImage\": \"/img/rgbaImage\"},{\"timestamp\": 3201,\"frameId\": 63,\"items\": [ {\"id\": 0,\"name\": \"blob1\",\"weight\": 0,\"confidence\": 1,\"color\": \"#0000FF\",\"dimension\": { \"width\": 0.044311594218015671, \"height\": 0.15963709354400635, \"depth\": 0.044311594218015671},\"position\": { \"x\": 0.28055679798126221, \"y\": 0.023770391941070557, \"z\": 0.038520518690347672},\"quaternion\": { \"w\": -0.018691437318921089, \"x\": 0.74761569499969482, \"y\": -0.044893074780702591, \"z\": -0.66234886646270752},\"orientation\": { \"pitch\": -5.01507568359375, \"yaw\": -97.0281982421875, \"roll\": -177.56260681152344},\"extremePoints\": {},\"pathPoints\": {},\"parentCamera\": \"rs1\" }],\"rgbaImage\": \"/img/rgbaImage\"}]}'
  _OCELLUSMODULEDATASERVICE._options = None
  _OCELLUSMODULEDATASERVICE._serialized_options = b'\222A!\022\037Serves data produced by modules'
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetModuleData']._options = None
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetModuleData']._serialized_options = b'\222A-\032+Querys the data for the specified module id\202\323\344\223\0021\022\022/api/v1/{moduleId}Z\033\022\031/api/v1/{moduleId}/{path}'
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetAllData']._options = None
  _OCELLUSMODULEDATASERVICE.methods_by_name['GetAllData']._serialized_options = b'\222A*\032(Returns all data produced by all modules\202\323\344\223\002\t\022\007/api/v1'
  _GETMODULEDATAREQUEST._serialized_start=183
  _GETMODULEDATAREQUEST._serialized_end=584
  _GETALLDATARESPONSE._serialized_start=587
  _GETALLDATARESPONSE._serialized_end=2709
  _OCELLUSMODULEDATASERVICE._serialized_start=2712
  _OCELLUSMODULEDATASERVICE._serialized_end=3149
# @@protoc_insertion_point(module_scope)
