# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import ocellus_api_module_data_service_pb2 as api_dot_v1_dot_ocellus__api__module__data__service__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


class OcellusModuleDataServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModuleData = channel.unary_unary(
                '/ocellus.api.v1.module.data.OcellusModuleDataService/GetModuleData',
                request_serializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.GetAllData = channel.unary_unary(
                '/ocellus.api.v1.module.data.OcellusModuleDataService/GetAllData',
                request_serializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetAllDataResponse.FromString,
                )


class OcellusModuleDataServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetModuleData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusModuleDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModuleData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModuleData,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'GetAllData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllData,
                    request_deserializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetAllDataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.api.v1.module.data.OcellusModuleDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusModuleDataService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetModuleData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.data.OcellusModuleDataService/GetModuleData',
            api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.module.data.OcellusModuleDataService/GetAllData',
            api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetModuleDataRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__module__data__service__pb2.GetAllDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
