# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/v1/ocellus_api_command_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(api/v1/ocellus_api_command_service.proto\x12\x16ocellus.api.v1.command\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\x8f\x01\n\x17GetCameraCommandRequest\x12Y\n\x02id\x18\x01 \x01(\tBM\x92\x41J2CThe camera name to change the current camera in single monitor mode\xd2\x01\x02id:\x19\x92\x41\x16\x32\x14\x12\x12id=\"Editor Camera\"\"\x8a\x01\n\x1bGetScreenshotCommandRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61meras\x18\x02 \x03(\t:L\x92\x41I2G\x12\x45/api/v1/cmd/screenshot?path=test%2Fsubfulder&cameras=rs1&cameras=img1\"\x99\x02\n\x17GetRecordCommandRequest\x12L\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32<.ocellus.api.v1.command.GetRecordCommandRequest.RecordAction\x12r\n\x04path\x18\x02 \x01(\tBd\x92\x41\x61\x32XRelative path to the directory recording will be stored in from the ocellus media folder\xd2\x01\x04path\"<\n\x0cRecordAction\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05START\x10\x01\x12\x08\n\x04STOP\x10\x02\x12\n\n\x06STATUS\x10\x03\"%\n\x15GetLoadCommandRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xc3\x01\n\x16GetPauseCommandRequest\x12X\n\x02id\x18\x01 \x01(\tBL\x92\x41I2GThe name of the module to pause. If absent, all modules will be paused.\x12O\n\x05query\x18\x02 \x01(\x08\x42@\x92\x41=2;If set, will return the modules which are currently paused.\"\x8c\x01\n\rRecordingFile\x12\x13\n\x0b\x65lapsedTime\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tthumbnail\x18\x03 \x01(\t\x12\x10\n\x08mimeType\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x13\n\x0bisDirectory\x18\x06 \x01(\x08\x12\x10\n\x08\x64\x61teTime\x18\x07 \x01(\t\"x\n\x16GetSaveCommandResponse\x12\x0c\n\x04name\x18\x01 \x01(\t:P\x92\x41M2K\x12I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}\"P\n\x18GetRecordCommandResponse\x12\x34\n\x05\x66iles\x18\x01 \x03(\x0b\x32%.ocellus.api.v1.command.RecordingFile\"T\n\x1cGetScreenshotCommandResponse\x12\x34\n\x05\x66iles\x18\x01 \x03(\x0b\x32%.ocellus.api.v1.command.RecordingFile\"x\n\x16GetLoadCommandResponse\x12\x0c\n\x04name\x18\x01 \x01(\t:P\x92\x41M2K\x12I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}\"\x89\x01\n\x18GetCameraCommandResponse\x12M\n\x02id\x18\x01 \x01(\tBA\x92\x41>27The name of the camera which was successfully chaged to\xd2\x01\x02id:\x1e\x92\x41\x1b\x32\x19\x12\x17{\"id\": \"Editor Camera\"}\"\x95\x01\n\x17GetPauseCommandResponse\x12K\n\x06states\x18\x01 \x03(\x0b\x32;.ocellus.api.v1.command.GetPauseCommandResponse.StatesEntry\x1a-\n\x0bStatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x32\xb3\x0c\n\x15OcellusCommandService\x12\xc3\x01\n\x10GetCameraCommand\x12/.ocellus.api.v1.command.GetCameraCommandRequest\x1a\x30.ocellus.api.v1.command.GetCameraCommandResponse\"L\x92\x41/\x1a-Sets the active camera in Single Monitor Mode\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/cmd/camera\x12\xbc\x04\n\x14GetScreenshotCommand\x12\x33.ocellus.api.v1.command.GetScreenshotCommandRequest\x1a\x34.ocellus.api.v1.command.GetScreenshotCommandResponse\"\xb8\x03\x92\x41\x96\x03\x1a\x93\x03\x45xecutes screenshot command. This does all of the following:\n1) Takes a screenshot from all canvases in unity for all pipelines\n2) Creates PCD files for each generated pointcloud\n3) Dumps all current the outputs of each module to a respective OMD file\n4) If decorated screenshots have been enabled throught the OcellusConfigService.UpdateConfig rpc, wysiwyg screenshots for each canvas will be exported\n\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/cmd/screenshot\x12\xae\x01\n\x10GetRecordCommand\x12/.ocellus.api.v1.command.GetRecordCommandRequest\x1a\x30.ocellus.api.v1.command.GetRecordCommandResponse\"7\x92\x41\x1a\x1a\x18Video recording commands\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/cmd/record\x12\xa3\x01\n\x0eGetSaveCommand\x12\x16.google.protobuf.Empty\x1a..ocellus.api.v1.command.GetSaveCommandResponse\"I\x92\x41.\x1a,Saves the current user configuration to disk\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/cmd/save\x12\xb1\x01\n\x0eGetLoadCommand\x12-.ocellus.api.v1.command.GetLoadCommandRequest\x1a..ocellus.api.v1.command.GetLoadCommandResponse\"@\x92\x41%\x1a#Restore to last saved configuration\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/cmd/load\x12\xd0\x01\n\x0fGetPauseCommand\x12..ocellus.api.v1.command.GetPauseCommandRequest\x1a/.ocellus.api.v1.command.GetPauseCommandResponse\"\\\x92\x41@\x1a>Will pause execution of module(s) and freeze the current state\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/cmd/pause\x1a\x37\x92\x41\x34\x12\x32\x41 collection of commands triggered by GET requestsBx\n\x1a\x63om.ocellus.api.v1.commandB\x15OcellusCommandServiceP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x07OAPICMD\xaa\x02\x16Ocellus.Api.V1.Commandb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v1.ocellus_api_command_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.ocellus.api.v1.commandB\025OcellusCommandServiceP\001Z\036github.com/byte-motion/ocellus\242\002\007OAPICMD\252\002\026Ocellus.Api.V1.Command'
  _GETCAMERACOMMANDREQUEST.fields_by_name['id']._options = None
  _GETCAMERACOMMANDREQUEST.fields_by_name['id']._serialized_options = b'\222AJ2CThe camera name to change the current camera in single monitor mode\322\001\002id'
  _GETCAMERACOMMANDREQUEST._options = None
  _GETCAMERACOMMANDREQUEST._serialized_options = b'\222A\0262\024\022\022id=\"Editor Camera\"'
  _GETSCREENSHOTCOMMANDREQUEST._options = None
  _GETSCREENSHOTCOMMANDREQUEST._serialized_options = b'\222AI2G\022E/api/v1/cmd/screenshot?path=test%2Fsubfulder&cameras=rs1&cameras=img1'
  _GETRECORDCOMMANDREQUEST.fields_by_name['path']._options = None
  _GETRECORDCOMMANDREQUEST.fields_by_name['path']._serialized_options = b'\222Aa2XRelative path to the directory recording will be stored in from the ocellus media folder\322\001\004path'
  _GETPAUSECOMMANDREQUEST.fields_by_name['id']._options = None
  _GETPAUSECOMMANDREQUEST.fields_by_name['id']._serialized_options = b'\222AI2GThe name of the module to pause. If absent, all modules will be paused.'
  _GETPAUSECOMMANDREQUEST.fields_by_name['query']._options = None
  _GETPAUSECOMMANDREQUEST.fields_by_name['query']._serialized_options = b'\222A=2;If set, will return the modules which are currently paused.'
  _GETSAVECOMMANDRESPONSE._options = None
  _GETSAVECOMMANDRESPONSE._serialized_options = b'\222AM2K\022I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}'
  _GETLOADCOMMANDRESPONSE._options = None
  _GETLOADCOMMANDRESPONSE._serialized_options = b'\222AM2K\022I{\"name\": \"/home/ocellus/.config/unity3d/Byte Motion/Ocellus/default.ocl\"}'
  _GETCAMERACOMMANDRESPONSE.fields_by_name['id']._options = None
  _GETCAMERACOMMANDRESPONSE.fields_by_name['id']._serialized_options = b'\222A>27The name of the camera which was successfully chaged to\322\001\002id'
  _GETCAMERACOMMANDRESPONSE._options = None
  _GETCAMERACOMMANDRESPONSE._serialized_options = b'\222A\0332\031\022\027{\"id\": \"Editor Camera\"}'
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._options = None
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._serialized_options = b'8\001'
  _OCELLUSCOMMANDSERVICE._options = None
  _OCELLUSCOMMANDSERVICE._serialized_options = b'\222A4\0222A collection of commands triggered by GET requests'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetCameraCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetCameraCommand']._serialized_options = b'\222A/\032-Sets the active camera in Single Monitor Mode\202\323\344\223\002\024\022\022/api/v1/cmd/camera'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetScreenshotCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetScreenshotCommand']._serialized_options = b'\222A\226\003\032\223\003Executes screenshot command. This does all of the following:\n1) Takes a screenshot from all canvases in unity for all pipelines\n2) Creates PCD files for each generated pointcloud\n3) Dumps all current the outputs of each module to a respective OMD file\n4) If decorated screenshots have been enabled throught the OcellusConfigService.UpdateConfig rpc, wysiwyg screenshots for each canvas will be exported\n\202\323\344\223\002\030\022\026/api/v1/cmd/screenshot'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetRecordCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetRecordCommand']._serialized_options = b'\222A\032\032\030Video recording commands\202\323\344\223\002\024\022\022/api/v1/cmd/record'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetSaveCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetSaveCommand']._serialized_options = b'\222A.\032,Saves the current user configuration to disk\202\323\344\223\002\022\022\020/api/v1/cmd/save'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetLoadCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetLoadCommand']._serialized_options = b'\222A%\032#Restore to last saved configuration\202\323\344\223\002\022\022\020/api/v1/cmd/load'
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetPauseCommand']._options = None
  _OCELLUSCOMMANDSERVICE.methods_by_name['GetPauseCommand']._serialized_options = b'\222A@\032>Will pause execution of module(s) and freeze the current state\202\323\344\223\002\023\022\021/api/v1/cmd/pause'
  _GETCAMERACOMMANDREQUEST._serialized_start=174
  _GETCAMERACOMMANDREQUEST._serialized_end=317
  _GETSCREENSHOTCOMMANDREQUEST._serialized_start=320
  _GETSCREENSHOTCOMMANDREQUEST._serialized_end=458
  _GETRECORDCOMMANDREQUEST._serialized_start=461
  _GETRECORDCOMMANDREQUEST._serialized_end=742
  _GETRECORDCOMMANDREQUEST_RECORDACTION._serialized_start=682
  _GETRECORDCOMMANDREQUEST_RECORDACTION._serialized_end=742
  _GETLOADCOMMANDREQUEST._serialized_start=744
  _GETLOADCOMMANDREQUEST._serialized_end=781
  _GETPAUSECOMMANDREQUEST._serialized_start=784
  _GETPAUSECOMMANDREQUEST._serialized_end=979
  _RECORDINGFILE._serialized_start=982
  _RECORDINGFILE._serialized_end=1122
  _GETSAVECOMMANDRESPONSE._serialized_start=1124
  _GETSAVECOMMANDRESPONSE._serialized_end=1244
  _GETRECORDCOMMANDRESPONSE._serialized_start=1246
  _GETRECORDCOMMANDRESPONSE._serialized_end=1326
  _GETSCREENSHOTCOMMANDRESPONSE._serialized_start=1328
  _GETSCREENSHOTCOMMANDRESPONSE._serialized_end=1412
  _GETLOADCOMMANDRESPONSE._serialized_start=1414
  _GETLOADCOMMANDRESPONSE._serialized_end=1534
  _GETCAMERACOMMANDRESPONSE._serialized_start=1537
  _GETCAMERACOMMANDRESPONSE._serialized_end=1674
  _GETPAUSECOMMANDRESPONSE._serialized_start=1677
  _GETPAUSECOMMANDRESPONSE._serialized_end=1826
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._serialized_start=1781
  _GETPAUSECOMMANDRESPONSE_STATESENTRY._serialized_end=1826
  _OCELLUSCOMMANDSERVICE._serialized_start=1829
  _OCELLUSCOMMANDSERVICE._serialized_end=3416
# @@protoc_insertion_point(module_scope)
