# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import ocellus_api_command_service_pb2 as api_dot_v1_dot_ocellus__api__command__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class OcellusCommandServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCameraCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetCameraCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandResponse.FromString,
                )
        self.GetScreenshotCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetScreenshotCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandResponse.FromString,
                )
        self.GetRecordCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetRecordCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandResponse.FromString,
                )
        self.GetSaveCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetSaveCommand',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetSaveCommandResponse.FromString,
                )
        self.GetLoadCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetLoadCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandResponse.FromString,
                )
        self.GetPauseCommand = channel.unary_unary(
                '/ocellus.api.v1.command.OcellusCommandService/GetPauseCommand',
                request_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandRequest.SerializeToString,
                response_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandResponse.FromString,
                )


class OcellusCommandServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCameraCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScreenshotCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecordCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSaveCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLoadCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPauseCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OcellusCommandServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCameraCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCameraCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandResponse.SerializeToString,
            ),
            'GetScreenshotCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScreenshotCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandResponse.SerializeToString,
            ),
            'GetRecordCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecordCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandResponse.SerializeToString,
            ),
            'GetSaveCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSaveCommand,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetSaveCommandResponse.SerializeToString,
            ),
            'GetLoadCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLoadCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandResponse.SerializeToString,
            ),
            'GetPauseCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPauseCommand,
                    request_deserializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandRequest.FromString,
                    response_serializer=api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocellus.api.v1.command.OcellusCommandService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OcellusCommandService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCameraCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetCameraCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetCameraCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScreenshotCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetScreenshotCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetScreenshotCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecordCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetRecordCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetRecordCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSaveCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetSaveCommand',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetSaveCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLoadCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetLoadCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetLoadCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPauseCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ocellus.api.v1.command.OcellusCommandService/GetPauseCommand',
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandRequest.SerializeToString,
            api_dot_v1_dot_ocellus__api__command__service__pb2.GetPauseCommandResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
